@@ -12,11 +12,14 @@ expect_aligned <- function(A, B, tol=.01){
   # https://math.stackexchange.com/questions/2113634/
 
   dotprod <- colSums(A*B) / sqrt( colSums(A*A) * colSums(B*B) )
-  # use abs() so that vectors which point in nearly opposite
+  # Note: Use abs() so that vectors which point in nearly opposite
   # directions ( dotprod= -1 ) can be considered as if pointing
   # in the same direction.
-  # dotprod could be slightly larger than 1.0, so subtract eps.
-  theta <- acos( abs(dotprod) - .Machine$double.eps )
+  # Note: we need to make sure elements of dotprod are not bigger
+  # than 1.0, which sometimes happens due to floating point error.
+  # theta[i] is the angle between A[,i] and B[,i]
+  #theta <- acos( abs(dotprod) - .Machine$double.eps )
+  theta <- acos( pmin( abs(dotprod), 1 ) )
   # average radian angle between pair-wise columns of A and B
   avg_angle <- mean(theta)
   expect_lt(avg_angle, tol)
